@@ -6,46 +6,48 @@ use open ':locale';
 use base 'Exporter';
 use base 'POD2::Base';
 
-our $VERSION = '5.16.1.03';
+our $VERSION = '5.16.2.01';
 
 our @EXPORT = qw(print_pod print_pods);
 
 # Versions list
 sub pod_info {{
-    perl              => '5.16.1',
-    perlbook          => '5.16.1',
-    perlboot          => '5.16.1',
-    perlbot           => '5.16.1',
-    perlclib          => '5.16.1',
-    perlcommunity     => '5.16.1',
-    perldata          => '5.16.1',
-    perldbmfilter     => '5.16.1',
-    perldoc           => '5.16.1',
-    perlexperiment    => '5.16.1',
-    perlfaq1          => '5.16.1',
-    perlfaq2          => '5.16.1',
-    perlfreebsd       => '5.16.1',
-    perlhacktut       => '5.16.1',
-    perlhist          => '5.16.1',
-    perlhurd          => '5.16.1',
-    perlintro         => '5.16.1',
-    perlmod           => '5.16.1',
-    perlmodinstall    => '5.16.1',
-    perlmroapi        => '5.16.1',
-    perlnewmod        => '5.16.1',
-    perlnumber        => '5.16.1',
-    perlobj           => '5.16.1',
-    perlootut         => '5.16.1',
-    perlopenbsd       => '5.16.1',
-    perlpragma        => '5.16.1',
-    perlsource        => '5.16.1',
-    perlstyle         => '5.16.1',
-    perltodo          => '5.16.1',
-    perltooc          => '5.16.1',
-    perltoot          => '5.16.1',
-    perlunifaq        => '5.16.1',
-    perlunitut        => '5.16.1',
-    perlutil          => '5.16.1',
+    perl              => '5.16.2',
+    perlbook          => '5.16.2',
+    perlboot          => '5.16.2',
+    perlbot           => '5.16.2',
+    perlcheat         => '5.16.2',
+    perlclib          => '5.16.2',
+    perlcommunity     => '5.16.2',
+    perldata          => '5.16.2',
+    perldbmfilter     => '5.16.2',
+    perldoc           => '5.16.2',
+    perlexperiment    => '5.16.2',
+    perlfaq1          => '5.16.2',
+    perlfaq2          => '5.16.2',
+    perlfreebsd       => '5.16.2',
+    perlglossary      => '5.16.2',
+    perlhacktut       => '5.16.2',
+    perlhist          => '5.16.2',
+    perlhurd          => '5.16.2',
+    perlintro         => '5.16.2',
+    perlmod           => '5.16.2',
+    perlmodinstall    => '5.16.2',
+    perlmroapi        => '5.16.2',
+    perlnewmod        => '5.16.2',
+    perlnumber        => '5.16.2',
+    perlobj           => '5.16.2',
+    perlootut         => '5.16.2',
+    perlopenbsd       => '5.16.2',
+    perlpragma        => '5.16.2',
+    perlsource        => '5.16.2',
+    perlstyle         => '5.16.2',
+    perltodo          => '5.16.2',
+    perltooc          => '5.16.2',
+    perltoot          => '5.16.2',
+    perlunifaq        => '5.16.2',
+    perlunitut        => '5.16.2',
+    perlutil          => '5.16.2',
 }};
 
 # String for perldoc with -L switch
